pub fn write_callsign_list(entries: &[CallsignEntry]) -> Vec<u8> ⓘExpand description
Generates a callsign list TSV file as UTF-16LE bytes with BOM.
The output includes a header row followed by one row per entry.
pub fn write_callsign_list(entries: &[CallsignEntry]) -> Vec<u8> ⓘGenerates a callsign list TSV file as UTF-16LE bytes with BOM.
The output includes a header row followed by one row per entry.